@@ -16,19 +16,43 @@
 struct XorrisO; 
 
 
-#define Xorriso_program_versioN "0.4.8"
+#define Xorriso_program_versioN "0.5.6"
+#define Xorriso_program_patch_leveL ""
 
 
 /* --------------------- Fundamental Management ------------------- */
 
 
 /* Get the version text (e.g. "0.4.2") of the program code.
+   This may differ from Xorriso_program_versioN if xorriso is dynamically
+   linked to an application.
    @param flag     unused yet, submit 0
    @return         readonly character string
 */
 char *Xorriso__get_version_text(int flag);
 
 
+/* Get the patch level text (e.g. "" or ".pl01") of the program code.
+   @param flag     unused yet, submit 0
+   @return         readonly character string
+*/
+char *Xorriso__get_patch_level_text(int flag);
+
+
+/* Choose how Xorriso_startup_libraries() and the XorrisO object shall
+   prepare for eventual signals.
+   @param behavior Default is behavior 1.
+                   0= no own signal handling. The main application has to do
+                      that. Do not start burn runs without any handling !
+                   1= use libburn signal handler. Most time with action
+                      0. During writing, formatting, blanking: 0x30.
+                      Only usable with a single xorriso object.
+   @param flag     unused yet, submit 0
+   @return         <= 0 is error, >0 is success
+*/
+int Xorriso__preset_signal_behavior(int behavior, int flag);
+
+
 /* Mandatory call:
    Create a new xorriso object and tell it the program name to be used
    with messages and for decision of special behavior.
@@ -887,6 +911,8 @@ int Xorriso_option_rom_toc_scan(struct XorrisO *xorriso, char *mode,
 /* Option -scdbackup_tag */
 int Xorriso_option_scdbackup_tag(struct XorrisO *xorriso, char *list_path,
                                  char *record_name, int flag);
+/* Option -scsi_log */
+int Xorriso_option_scsi_log(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Option -session_log */
 int Xorriso_option_session_log(struct XorrisO *xorriso, char *path, int flag);
@@ -978,6 +1004,10 @@ int Xorriso_option_volid(struct XorrisO *xorriso, char *volid, int flag);
 /* Option -volset_id */
 int Xorriso_option_volset_id(struct XorrisO *xorriso, char *name, int flag);
 
+/* Option -volume_date */
+int Xorriso_option_volume_date(struct XorrisO *xorriso,
+                               char *time_type, char *timestring, int flag);
+
 /* Option -xattr "on"|"off" */
 int Xorriso_option_xattr(struct XorrisO *xorriso, char *mode, int flag);
 
